/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.fleet.machine.windows.MachineOverviewController;
import nl.cloudfarming.client.fleet.model.MachineProvider;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

@MultiViewElement.Registration(displayName = "#LBL_Vehicle_Data",
iconBase = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png",
mimeType = "application/x-agrosense-vehicle",
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "Vehicle",
position = 1000)
@Messages({"LBL_Vehicle_Data=Data", "unknownPropertyValue=Unknown"})
public final class VehicleDataElement extends MachineOverviewController<VehicleOverviewPanel> implements MultiViewElement {

    private VehicleDataObject obj;
    private Vehicle vehicle;
    private JToolBar toolbar = new JToolBar();
    private ASBodyPanel overviewDecorator;
    private transient MultiViewElementCallback callback;
    private VehicleOverviewPanel vehicleOverviewPanel;

    public VehicleDataElement(Lookup lkp) {
        super(new VehicleOverviewPanel(lkp.lookup(Vehicle.class)) , lkp.lookup(Vehicle.class), Lookup.getDefault().lookupAll(VehicleDataService.class));
        obj = lkp.lookup(VehicleDataObject.class);
        vehicle = obj.getLookup().lookup(Vehicle.class);
        vehicle.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if (Vehicle.PROP_NAME.equals(evt.getPropertyName())) {
                    updateName();
                }
            }
        });
    }

    @Override
    public JComponent getVisualRepresentation() {
        if (overviewDecorator == null) {
            overviewDecorator = new ASBodyPanel(getOverviewPanel());
            overviewDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png", true));
        }
        return overviewDecorator;
    }

    @Override
    public MachineProvider getMachineProvider() {
        return Lookup.getDefault().lookup(VehicleManagerImpl.class);
    }

    @Override
    public Project getProject() {
        return EnterpriseIdProvider.ProjectFinder.find(vehicle.getURI());
    }

    @Override
    public void fieldsUpdated() {
        updateName();
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
        OpenCloseHandler.Event.triggerOpen(obj.getNodeDelegate());
    }

    @Override
    public void componentClosed() {
        OpenCloseHandler.Event.triggerClose(obj.getNodeDelegate());
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(vehicle.getName());
            tc.setDisplayName(vehicle.getName());
            tc.setName(vehicle.getName());
            tc.setToolTipText(vehicle.getName());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
