/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle;

import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;
import nl.cloudfarming.client.fleet.machine.windows.MachineOverviewPanel;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.util.swing.FormRow;
import org.jdesktop.beansbinding.AutoBinding;
import org.jdesktop.beansbinding.BeanProperty;
import org.jdesktop.beansbinding.BindingGroup;
import org.jdesktop.beansbinding.Bindings;
import org.openide.util.NbBundle;

/**
 * Overview panel for vehicles
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"VehicleOverviewPanel horse power label text=Horse power:",
    "VehicleOverviewPanel fuel tank capacity label text=Fuel tank capacity:",
    "VehicleOverviewPanel displacement label text=Displacement:"
})
public class VehicleOverviewPanel extends MachineOverviewPanel {
    private static final double DISPLACEMENT_STEP_SIZE = 0.1;
    private static final double DISPLACEMENT_MIN_VALUE = 0.1;

    private JSpinner horsePowerSpinner;
    private JSpinner fuelTankCapacitySpinnen;
    private JSpinner displacementSpinner;
    private Vehicle vehicle;

    public VehicleOverviewPanel(Vehicle vehicle) {
        this.vehicle = vehicle;
        initComponents();
        bind();
    }

    private void initComponents() {
        horsePowerSpinner = new JSpinner();
        fuelTankCapacitySpinnen = new JSpinner();
        displacementSpinner = new JSpinner(new SpinnerNumberModel(DISPLACEMENT_MIN_VALUE, DISPLACEMENT_MIN_VALUE, Double.MAX_VALUE, DISPLACEMENT_STEP_SIZE));

        FormRow horsePowerRow = new FormRow(false, Bundle.VehicleOverviewPanel_horse_power_label_text(), Bundle.VehicleOverviewPanel_horse_power_label_text(), horsePowerSpinner);
        FormRow fuelTankCapacityRow = new FormRow(false, Bundle.VehicleOverviewPanel_fuel_tank_capacity_label_text(), Bundle.VehicleOverviewPanel_fuel_tank_capacity_label_text(), fuelTankCapacitySpinnen);
        FormRow displacementRow = new FormRow(false, Bundle.VehicleOverviewPanel_displacement_label_text(), Bundle.VehicleOverviewPanel_displacement_label_text(), displacementSpinner);

        add(horsePowerRow);
        add(fuelTankCapacityRow);
        add(displacementRow);
    }

    private void bind() {
        BindingGroup vehicleBindingGroup = new BindingGroup();
        BeanProperty fieldPropHorsepower = BeanProperty.create(Vehicle.PROP_HORSEPOWER);
        BeanProperty formPropHorsepower = BeanProperty.create("value");
        BeanProperty fieldPropFuelTankCapacity = BeanProperty.create(Vehicle.PROP_FUELTANKCAPACITY);
        BeanProperty formPropFuelTankCapacity = BeanProperty.create("value");
        BeanProperty fieldPropDisplacement = BeanProperty.create(Vehicle.PROP_DISPLACEMENT);
        BeanProperty formPropDisplacement = BeanProperty.create("value");

        vehicleBindingGroup.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE, vehicle, fieldPropHorsepower, horsePowerSpinner, formPropHorsepower));
        vehicleBindingGroup.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE, vehicle, fieldPropFuelTankCapacity, fuelTankCapacitySpinnen, formPropFuelTankCapacity));
        vehicleBindingGroup.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE, vehicle, fieldPropDisplacement, displacementSpinner, formPropDisplacement));
        vehicleBindingGroup.bind();
    }

    public JSpinner getDisplacementSpinner() {
        return displacementSpinner;
    }

    public JSpinner getFuelTankCapacitySpinnen() {
        return fuelTankCapacitySpinnen;
    }

    public JSpinner getHorsePowerSpinner() {
        return horsePowerSpinner;
    }
}
