/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle.tree;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import nl.cloudfarming.client.fleet.machine.tree.MachineNode;
import nl.cloudfarming.client.fleet.model.Machine.MachineMetaInfo;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.model.VehicleManager;
import org.openide.nodes.Node;
import org.openide.util.Lookup;

/**
 *
 * @author Maciek Dulkiewicz && Wytse Visser
 */
public class VehicleNode extends MachineNode {
    
    public VehicleNode(Node node) {
        super(node);
        Vehicle vehicle = node.getLookup().lookup(Vehicle.class);
        assert vehicle != null:"VehicleNode should have a Vehicle instance in its lookup";
        vehicle.addPropertyChangeListener(new PropertyChangeListener() {
            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if (Vehicle.PROP_NAME.equals(evt.getPropertyName())) {
                    setName((String) evt.getNewValue());
                    setDisplayName(getName());
                }
            }
        });
    }
    
    @Override
    protected void saveMachine() {
        Lookup.getDefault().lookup(VehicleManager.class).save((Vehicle) getMachine());
    }

    @Override
    protected MachineMetaInfo getMetaInfo() {
        return new VehicleInfo();
    }
    
    public class VehicleInfo implements MachineMetaInfo {

        private final String ICON_SMALL = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_316.png";
        private final String ICON_LARGE = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_332.png";

        @Override
        public String getDisplayName() {
            return getMachine().getName();
        }

        @Override
        public String getSmallIconResource() {
            return ICON_SMALL;
        }

        @Override
        public String getLargeIconResource() {
            return ICON_LARGE;
        }
    }
}