/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.util.Calendar;
import java.util.LinkedList;
import java.util.List;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardFactory;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardOverviewPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardPanel;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardStartPanel;
import nl.cloudfarming.client.fleet.model.MachineProvider;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.fleet.vehicle.VehicleDataService;
import nl.cloudfarming.client.fleet.vehicle.VehicleManagerImpl;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.util.NbBundle;

/**
 * Wizard factory for vehicles
 * @author Wytse Visser
 */
@NbBundle.Messages({"VehicleWizardFactory year label text=Year",
                    "VehicleWizardFactory purchase date label text=Purchase date",
                    "VehicleWizardFactory purchase price label text=Purchase price",
                    "VehicleWizardFactory mileage label text=Mileage",
                    "VehicleWizardFactory horsepower label text=Horsepower",
                    "VehicleWizardFactory displacement label text=Displacement (L)",
                    "VehicleWizardFactory fuel tank capacity label text=Fuel tank capacity (L)"})
class VehicleWizardFactory extends MachineWizardFactory {

    public VehicleWizardFactory(Project project) {
        super(project);
    }

    @Override
    public MachineWizardPanel createOverviewPanel() {
        MachineWizardOverviewPanel panel = new MachineWizardOverviewPanel();
        panel.addProperty(Vehicle.PROP_YEAR, Bundle.VehicleWizardFactory_year_label_text());
        panel.addProperty(Vehicle.PROP_PURCHASEDATE, Bundle.VehicleWizardFactory_purchase_date_label_text());
        panel.addProperty(Vehicle.PROP_PURCHASEPRICE, Bundle.VehicleWizardFactory_purchase_price_label_text());
        panel.addProperty(Vehicle.PROP_MILEAGE, Bundle.VehicleWizardFactory_mileage_label_text());
        panel.addProperty(Vehicle.PROP_HORSEPOWER, Bundle.VehicleWizardFactory_horsepower_label_text());
        panel.addProperty(Vehicle.PROP_DISPLACEMENT, Bundle.VehicleWizardFactory_displacement_label_text());
        panel.addProperty(Vehicle.PROP_FUELTANKCAPACITY, Bundle.VehicleWizardFactory_fuel_tank_capacity_label_text());

        return panel;
    }

    @Override
    public List<WizardDescriptor.Panel<WizardDescriptor>> createInitialPanels() {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new LinkedList<>();
        EnterpriseIdProvider eip = getProject().getLookup().lookup(EnterpriseIdProvider.class);
        final int currentYear = Calendar.getInstance().get(Calendar.YEAR);
        Vehicle vehicle = new Vehicle(eip, ""); 
        vehicle.setYear(currentYear);
        panels.add(new MachineWizardStartPanel(this, vehicle));
        panels.add(new VehicleWizardPanel2());
        return panels;
    }

    @Override
    public Class<? extends MachineDataService> getDataServiceClass() {
        return VehicleDataService.class;
    }

    @Override
    public Class<? extends MachineProvider> getMachineProviderClass() {
        return VehicleManagerImpl.class;
    }
}
