/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.fleet.vehicle.wizard;

import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.machine.MachineDataService;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardIterator;
import nl.cloudfarming.client.fleet.machine.wizard.MachineWizardPanel;
import nl.cloudfarming.client.fleet.model.Machine;
import nl.cloudfarming.client.fleet.model.Vehicle;
import org.openide.WizardDescriptor;

class VehicleWizardPanel2 extends MachineWizardPanel {

    private VehicleVisualPanel2 visualPanel;
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.vehicle.wizard");

    @Override
    protected VehicleVisualPanel2 getVisual() {
        if (visualPanel == null) {
            visualPanel = new VehicleVisualPanel2();
        }
        return visualPanel;
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
        setTitle(((Machine)wiz.getProperty(MachineWizardIterator.PROP_MACHINE)).getName());
        
        MachineDataService.Model model = (MachineDataService.Model) wiz.getProperty(MachineWizardIterator.PROP_MODEL);
        if(model != null) {
            getVisual().setHorsepowerValue(model.getProperty(Vehicle.PROP_HORSEPOWER));
            getVisual().setDisplacementValue(model.getProperty(Vehicle.PROP_DISPLACEMENT));
            getVisual().setFuelTankCapacityValue(model.getProperty(Vehicle.PROP_FUELTANKCAPACITY));
        } else {
            LOGGER.finest("No model present. Not entering any default values");
        }
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty(Vehicle.PROP_HORSEPOWER, getVisual().getHorsepowerValue());
        wiz.putProperty(Vehicle.PROP_DISPLACEMENT, getVisual().getDisplacementValue());
        wiz.putProperty(Vehicle.PROP_FUELTANKCAPACITY, getVisual().getFuelTankCapacityValue());
    }
}
